Sweeper Module
==============

.. autoclass:: zhinst.toolkit.control.drivers.base.SweeperModule
    :members:

Result Class for the Sweeper Module
-----------------------------------

.. autoclass:: zhinst.toolkit.control.drivers.base.sweeper.SweeperResult
    :members: